@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -313,7 +313,7 @@ passwd_main (const char *program, int argc, char **argv)
           print_help (program);
           return 0;
         case '\255':
-          print_version (program, "2003");
+          print_version (program, "2004");
           return 0;
         case '\254':
           print_usage (stdout, program);
@@ -431,7 +431,7 @@ passwd_main (const char *program, int argc, char **argv)
     }
 
 #ifdef WITH_SELINUX
-  if (is_selinux_enabled ())
+  if (is_selinux_enabled () > 0)
     {
       if ((getuid () == 0) &&
 	  (selinux_check_access (pw->pw_name, PASSWD__PASSWD) != 0))
@@ -440,14 +440,24 @@ passwd_main (const char *program, int argc, char **argv)
 	  if (getprevcon (&user_context) < 0)
 	    user_context =
 	      (security_context_t) strdup (_("Unknown user context"));
-	  syslog (LOG_ALERT,
-		  _("%s is not authorized to change the password of %s\n"),
-                  user_context, pw->pw_name);
-           fprintf (stderr,
-		 _("%s: %s is not authorized to change the password of %s\n"),
-		    program, user_context, pw->pw_name);
-           freecon (user_context);
-           exit (E_NOPERM);
+
+	  fprintf (stderr,
+		  _("%s: %s is not authorized to change the password of %s\n"),
+		   program, user_context, pw->pw_name);
+	  if (security_getenforce() > 0)
+	    {
+	      syslog (LOG_ALERT,
+		      "%s is not authorized to change the password of %s",
+		      user_context, pw->pw_name);
+	      freecon (user_context);
+	      exit (E_NOPERM);
+	    }
+	  else
+	    {
+	      fprintf (stderr,
+		       _("SELinux is in permissive mode, continuing\n"));
+	      freecon (user_context);
+	    }
 	}
     }
 #endif
